pub struct Esi { /* private fields */ }Implementations
Sourceimpl Esi
impl Esi
Sourcepub async fn get_alliances(
&self,
etag: Option<&str>,
) -> EsiResult<Response<Vec<i32>>>
pub async fn get_alliances( &self, etag: Option<&str>, ) -> EsiResult<Response<Vec<i32>>>
List all active player alliances esi: https://esi.evetech.net/latest/alliances/
Sourcepub async fn get_alliance(
&self,
alliance_id: i32,
etag: Option<&str>,
) -> EsiResult<Response<Alliance>>
pub async fn get_alliance( &self, alliance_id: i32, etag: Option<&str>, ) -> EsiResult<Response<Alliance>>
Public information about an alliance esi: https://esi.evetech.net/latest/alliances/{alliance_id}/
Sourcepub async fn get_alliance_corporations(
&self,
alliance_id: i32,
etag: Option<&str>,
) -> EsiResult<Response<Vec<i32>>>
pub async fn get_alliance_corporations( &self, alliance_id: i32, etag: Option<&str>, ) -> EsiResult<Response<Vec<i32>>>
List all current member corporations of an alliance esi: https://esi.evetech.net/latest/alliances/{alliance_id}/corporations/
Sourcepub async fn get_alliance_icons(
&self,
alliance_id: i32,
etag: Option<&str>,
) -> EsiResult<Response<AllianceIcon>>
pub async fn get_alliance_icons( &self, alliance_id: i32, etag: Option<&str>, ) -> EsiResult<Response<AllianceIcon>>
Get the icon urls for a alliance esi: https://esi.evetech.net/latest/alliances/{alliance_id}/icons/
Sourceimpl Esi
impl Esi
Sourcepub async fn get_character_assets(
&self,
character_id: i32,
access_token: &str,
page: Option<i32>,
etag: Option<&str>,
) -> EsiResult<Response<Paged<Vec<CharacterAsset>>>>
pub async fn get_character_assets( &self, character_id: i32, access_token: &str, page: Option<i32>, etag: Option<&str>, ) -> EsiResult<Response<Paged<Vec<CharacterAsset>>>>
Requires the following scope: esi-assets.read_assets.v1 Return a list of the characters assets esi: https://esi.evetech.net/latest/characters/{character_id}/assets/
Sourceimpl Esi
impl Esi
Sourcepub fn create_login_url(
&self,
scopes: Vec<Scope>,
) -> EsiResult<AuthenticationData>
pub fn create_login_url( &self, scopes: Vec<Scope>, ) -> EsiResult<AuthenticationData>
Sourcepub async fn get_token(
&self,
code: String,
) -> EsiResult<StandardTokenResponse<EmptyExtraTokenFields, BasicTokenType>>
pub async fn get_token( &self, code: String, ) -> EsiResult<StandardTokenResponse<EmptyExtraTokenFields, BasicTokenType>>
Sourcepub async fn refresh_token(
&self,
refresh_token: String,
) -> EsiResult<StandardTokenResponse<EmptyExtraTokenFields, BasicTokenType>>
pub async fn refresh_token( &self, refresh_token: String, ) -> EsiResult<StandardTokenResponse<EmptyExtraTokenFields, BasicTokenType>>
Sourcepub async fn validate_token(
&self,
token: &str,
) -> EsiResult<TokenData<EveJwtClaims>>
pub async fn validate_token( &self, token: &str, ) -> EsiResult<TokenData<EveJwtClaims>>
Sourceimpl Esi
impl Esi
Sourcepub async fn get_character(
&self,
character_id: i32,
etag: Option<&str>,
) -> EsiResult<Response<Character>>
pub async fn get_character( &self, character_id: i32, etag: Option<&str>, ) -> EsiResult<Response<Character>>
Public information about a character esi: https://esi.evetech.net/latest/characters/{character_id}/
Sourcepub async fn get_character_agents_research(
&self,
character_id: i32,
etag: Option<&str>,
) -> EsiResult<Response<Vec<i32>>>
pub async fn get_character_agents_research( &self, character_id: i32, etag: Option<&str>, ) -> EsiResult<Response<Vec<i32>>>
Requires the following scope: esi-characters.read_agents_research.v1 Return a list of agents research information for a character. The formula for finding the current research points with an agent is: currentPoints = remainderPoints + pointsPerDay * days(currentTime - researchStartDate) esi: https://esi.evetech.net/latest/characters/{character_id}/agents_research/
Sourcepub async fn post_character_affiliations(
&self,
character_ids: Vec<i32>,
) -> EsiResult<Vec<CharacterAffiliation>>
pub async fn post_character_affiliations( &self, character_ids: Vec<i32>, ) -> EsiResult<Vec<CharacterAffiliation>>
Bulk lookup of character IDs to corporation, alliance and faction Requires the following scope: esi-characters.read_corporation_roles.v1 esi: https://esi.evetech.net/latest/characters/{character_ids}/affiliation/
Sourceimpl Esi
impl Esi
pub async fn get_corporation( &self, corporation_id: i32, etag: Option<&str>, ) -> EsiResult<Response<Corporation>>
pub async fn get_corporation_structures( &self, corporation_id: i32, access_token: &str, etag: Option<&str>, ) -> EsiResult<Response<Vec<CorporationStructure>>>
Sourceimpl Esi
impl Esi
Sourcepub async fn get_character_recent_killmails(
&self,
character_id: i32,
access_token: &str,
etag: Option<&str>,
) -> EsiResult<Response<Vec<RecentKillmail>>>
pub async fn get_character_recent_killmails( &self, character_id: i32, access_token: &str, etag: Option<&str>, ) -> EsiResult<Response<Vec<RecentKillmail>>>
Requires the following scope: esi-killmails.read_killmails.v1 Return a list of a character’s kills and losses going back 90 days esi: https://esi.evetech.net/latest/characters/{character_id}/killmails/
Sourcepub async fn get_corporation_recent_killmails(
&self,
corporation_id: i32,
access_token: &str,
etag: Option<&str>,
) -> EsiResult<Response<Vec<RecentKillmail>>>
pub async fn get_corporation_recent_killmails( &self, corporation_id: i32, access_token: &str, etag: Option<&str>, ) -> EsiResult<Response<Vec<RecentKillmail>>>
Requires the following scope: esi-killmails.read_corporation_killmails.v1 Get a list of a corporation’s kills and losses going back 90 days esi: https://esi.evetech.net/latest/corporations/{corporation_id}/killmails/
Sourceimpl Esi
impl Esi
Sourcepub async fn get_character_location(
&self,
access_token: &str,
character_id: i32,
etag: Option<&str>,
) -> EsiResult<Response<CharacterLocation>>
pub async fn get_character_location( &self, access_token: &str, character_id: i32, etag: Option<&str>, ) -> EsiResult<Response<CharacterLocation>>
Requires the following scope: esi-location.read_location.v1 Information about the characters current location. Returns the current solar system id, and also the current station or structure ID if applicable esi: https://esi.evetech.net/latest/characters/{character_id}/location/
Sourcepub async fn get_character_online(
&self,
access_token: &str,
character_id: i32,
etag: Option<&str>,
) -> EsiResult<Response<CharacterOnline>>
pub async fn get_character_online( &self, access_token: &str, character_id: i32, etag: Option<&str>, ) -> EsiResult<Response<CharacterOnline>>
Requires the following scope: esi-location.read_online.v1 Checks if the character is currently online esi: https://esi.evetech.net/latest/characters/{character_id}/online/
Sourcepub async fn get_character_ship(
&self,
access_token: &str,
character_id: i32,
etag: Option<&str>,
) -> EsiResult<Response<CharacterShip>>
pub async fn get_character_ship( &self, access_token: &str, character_id: i32, etag: Option<&str>, ) -> EsiResult<Response<CharacterShip>>
Requires the following scope: esi-location.read_ship_type.v1 Get the current ship type, name and id esi: https://esi.evetech.net/latest/characters/{character_id}/ship/
Sourceimpl Esi
impl Esi
Sourcepub async fn get_character_orders(
&self,
access_token: &str,
character_id: i32,
etag: Option<&str>,
) -> EsiResult<Response<Vec<CharacterMarketOrder>>>
pub async fn get_character_orders( &self, access_token: &str, character_id: i32, etag: Option<&str>, ) -> EsiResult<Response<Vec<CharacterMarketOrder>>>
Get a list of orders in a character’s orders esi: https://esi.evetech.net/latest/characters/{character_id}/orders/
Sourcepub async fn get_character_orders_history(
&self,
access_token: &str,
character_id: i32,
page: Option<i32>,
etag: Option<&str>,
) -> EsiResult<Response<Paged<Vec<CharacterMarketOrder>>>>
pub async fn get_character_orders_history( &self, access_token: &str, character_id: i32, page: Option<i32>, etag: Option<&str>, ) -> EsiResult<Response<Paged<Vec<CharacterMarketOrder>>>>
Get a list of historical orders in a character’s orders esi: https://esi.evetech.net/latest/characters/{character_id}/orders/history/
Sourcepub async fn get_corporation_orders(
&self,
access_token: &str,
corporation_id: i32,
page: Option<i32>,
etag: Option<&str>,
) -> EsiResult<Response<Paged<Vec<CorporationMarketOrder>>>>
pub async fn get_corporation_orders( &self, access_token: &str, corporation_id: i32, page: Option<i32>, etag: Option<&str>, ) -> EsiResult<Response<Paged<Vec<CorporationMarketOrder>>>>
Get a list of orders in a corporation’s orders esi: https://esi.evetech.net/latest/corporations/{corporation_id}/orders/
Sourcepub async fn get_corporation_orders_history(
&self,
access_token: &str,
corporation_id: i32,
page: Option<i32>,
etag: Option<&str>,
) -> EsiResult<Response<Paged<Vec<CorporationMarketOrder>>>>
pub async fn get_corporation_orders_history( &self, access_token: &str, corporation_id: i32, page: Option<i32>, etag: Option<&str>, ) -> EsiResult<Response<Paged<Vec<CorporationMarketOrder>>>>
Get a list of historical orders in a corporation’s orders esi: https://esi.evetech.net/latest/corporations/{corporation_id}/orders/history/
Sourcepub async fn get_market_history(
&self,
region_id: i32,
type_id: i32,
etag: Option<&str>,
) -> EsiResult<Response<Vec<MarketHistory>>>
pub async fn get_market_history( &self, region_id: i32, type_id: i32, etag: Option<&str>, ) -> EsiResult<Response<Vec<MarketHistory>>>
Get a list of historical market statistics for a type in a region esi: https://esi.evetech.net/latest/markets/{region_id}/history/
Sourcepub async fn get_market_orders(
&self,
region_id: i32,
order_type: Option<&MarketOrderType>,
type_id: Option<i32>,
page: Option<i32>,
etag: Option<&str>,
) -> EsiResult<Response<Paged<Vec<MarketOrder>>>>
pub async fn get_market_orders( &self, region_id: i32, order_type: Option<&MarketOrderType>, type_id: Option<i32>, page: Option<i32>, etag: Option<&str>, ) -> EsiResult<Response<Paged<Vec<MarketOrder>>>>
Get a list of orders in a region esi: https://esi.evetech.net/latest/markets/{region_id}/orders/
Sourcepub async fn get_market_types(
&self,
region_id: i32,
page: Option<i32>,
etag: Option<&str>,
) -> EsiResult<Response<Paged<Vec<i32>>>>
pub async fn get_market_types( &self, region_id: i32, page: Option<i32>, etag: Option<&str>, ) -> EsiResult<Response<Paged<Vec<i32>>>>
Get a list of market types for a region esi: https://esi.evetech.net/latest/markets/{region_id}/types/
Sourcepub async fn get_market_groups(
&self,
etag: Option<&str>,
) -> EsiResult<Response<Paged<Vec<i32>>>>
pub async fn get_market_groups( &self, etag: Option<&str>, ) -> EsiResult<Response<Paged<Vec<i32>>>>
Get a list of market groups esi: https://esi.evetech.net/latest/markets/groups/
Sourcepub async fn get_market_group(
&self,
market_group_id: i32,
etag: Option<&str>,
) -> EsiResult<Response<MarketGroup>>
pub async fn get_market_group( &self, market_group_id: i32, etag: Option<&str>, ) -> EsiResult<Response<MarketGroup>>
Get a list of types in a market group esi: https://esi.evetech.net/latest/markets/groups/{market_group_id}/
pub async fn get_market_prices( &self, etag: Option<&str>, ) -> EsiResult<Response<Vec<MarketPrice>>>
Sourcepub async fn get_market_structure(
&self,
access_token: &str,
structure_id: i64,
etag: Option<&str>,
) -> EsiResult<Response<Vec<MarketOrder>>>
pub async fn get_market_structure( &self, access_token: &str, structure_id: i64, etag: Option<&str>, ) -> EsiResult<Response<Vec<MarketOrder>>>
Get a list of orders in a structure esi: https://esi.evetech.net/latest/markets/structures/{structure_id}/